from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.utils.translation import ugettext_lazy as _

from models import Fb
from models import PLUGIN_TEMPLATES


class FacebookAlbumPlugin(CMSPluginBase):
    model = Fb
    name = _("Facebook Album")
    render_template = PLUGIN_TEMPLATES[0][0]

    def render(self, context, instance, placeholder):
        if instance and instance.template:
            self.render_template = instance.template
        context.update({
            'object': instance,
        })
        return context

plugin_pool.register_plugin(FacebookAlbumPlugin)



from cms.models.pluginmodel import CMSPlugin
from django.utils.translation import ugettext_lazy as _
from django.db import models

PLUGIN_TEMPLATES = (
    ('cms_plugins/fb_album.html', 'Carousel effect'),
    ('cms_plugins/fb_album_lightbox.html', 'Light effect'),
)


class Fb(CMSPlugin):
    album_url = models.CharField(_('Album Url'), max_length=125)
    access_token = models.CharField('Access token', max_length=500)
    album_name = models.CharField('Album Name', max_length=75)
    template = models.CharField('Template', max_length=255,
        choices = PLUGIN_TEMPLATES)



from setuptools import setup, find_packages

version = '0.5.5'

setup(
    name='cmsplugin-fbalbum',
    version=version,
    description='facebook album plugin for django-cms',
    author='Vinit Kumar',
    author_email='vinit.kumar@changer.nl',
    url='http://github.com/vinitcool76/cmsplugin-fbalbum.git',
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    install_requires=[
    ],
)
